document.write("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr bgcolor=\"#cccccc\"><td height=\"1\"></td></tr>");
document.write("<tr bgcolor=\"#ffffff\"><td height=\"1\"></td></tr>");
document.write("</table>");
document.write("<table cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr height=\"24\"> ");
document.write("<td><img src=\"img/redo.gif\" alt=\"重做\" class=\"himg\" onclick=\"doExecute('redo')\"/></td>");
document.write("<td><img src=\"img/undo.gif\" alt=\"撒消\" class=\"himg\" onclick=\"doExecute('undo')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/swf.gif\" alt=\"插入Flash\" class=\"himg\" onclick=\"doInsertFlash()\"/></td>");
document.write("<td><img src=\"img/media.gif\" alt=\"插入多媒体文件\" class=\"himg\" onclick=\"doInsertMedia()\"/></td>");
document.write("<td><img src=\"img/img.gif\" alt=\"插入图片\" class=\"himg\" onclick=\"doInsertImage()\"/></td>");
document.write("<td><img src=\"img/table.gif\" alt=\"插入表格\" class=\"himg\" onclick=\"doInsertTable()\"/></td>");
document.write("<td><img src=\"img/addon.gif\" alt=\"插入附件\" class=\"himg\" onclick=\"doInsertAddon()\"/></td> ");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/link.gif\" alt=\"超链接\" class=\"himg\" onclick=\"doExecute('CreateLink')\"/></td>");
document.write("<td><img src=\"img/unlink.gif\" alt=\"取消链接\" class=\"himg\" onclick=\"doExecute('Unlink')\"/></td>");
document.write("<td><img src=\"img/anchor.gif\" alt=\"锚点\" width=\"23\" height=\"22\" class=\"himg\" onclick=\"doInsertAnchor()\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/color.gif\" alt=\"字体颜色\" class=\"himg\" onclick=\"doFontColor()\"></td>");
document.write("<td>");
document.write("<table cellspacing=\"0\" cellpadding=\"0\">");
document.write("<tr> ");
document.write("<td width=\"50\" align=\"center\">字体：</td>");
document.write("<td>");
document.write("<select name=\"selectFont\" id=\"selectFont\" style=\"width:80px;height:18px\" onChange=\"doFontName(this[this.selectedIndex].value);this.selectedIndex=0;\">");
document.write("<option value=\"0\">--默认--</option>");
document.write("<option value=\"宋体\">宋体</option>");
document.write("<option value=\"黑体\">黑体</option>");
document.write("<option value=\"楷体_GB2312\">楷体_GB2312</option>");
document.write("<option value=\"Arial\">Arial</option>");
document.write("<option value=\"Arial Black\">Arial Black</option>");
document.write("</select>");
document.write("</td>");
document.write("<td width=\"50\" align=\"center\">　大小：</td>");
document.write("<td>");
document.write("	<select name=\"selectSize\" id=\"selectSize\" style=\"width:80px;height:18px\" onChange=\"doFontSize(this[this.selectedIndex].value);this.selectedIndex=0;\">");
document.write("<option value=\"0\">默认</option>");
document.write("<option value=\"1\">1 (8pt)</option>");
document.write("<option value=\"2\">2 (10pt)</option>");
document.write("<option value=\"3\">3 (12pt)</option>");
document.write("<option value=\"4\">4 (14pt)</option>");
document.write("<option value=\"5\">5 (18pt)</option>");
document.write("<option value=\"6\">6 (24pt)</option>");
document.write("<option value=\"7\">7 (36pt)</option>");
document.write("</select>");
document.write(" </td>");
document.write("</tr>");
document.write("</table>");
document.write("</td>");
document.write("</tr>");
document.write("</table>");
document.write("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr bgcolor=\"#cccccc\"><td height=\"1\"></td></tr>");
document.write("<tr bgcolor=\"#ffffff\"><td height=\"1\"></td></tr>");
document.write("</table>");
document.write("<table cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr height=\"24\"> ");
document.write("<td><img src=\"img/ol.gif\" alt=\"数字项目列表\" class=\"himg\" onclick=\"doExecute('InsertOrderedList')\"/></td>");
document.write("<td><img src=\"img/dl.gif\" alt=\"普通项目列表\" class=\"himg\" onclick=\"doExecute('InsertUnorderedList')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/left.gif\" alt=\"左对齐\" class=\"himg\" onclick=\"doExecute('JustifyLeft')\"/></td>");
document.write("<td><img src=\"img/center.gif\" alt=\"居中对齐\" class=\"himg\" onclick=\"doExecute('JustifyCenter')\"/></td>");
document.write("<td><img src=\"img/right.gif\" alt=\"右对齐\" class=\"himg\" onclick=\"doExecute('JustifyRight')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/u.gif\" alt=\"下划线\" class=\"himg\" onclick=\"doExecute('Underline')\"/></td>");
document.write("<td><img src=\"img/b.gif\" alt=\"粗体\" class=\"himg\" onclick=\"doExecute('Bold')\"/></td>");
document.write("<td><img src=\"img/i.gif\" alt=\"斜体\" class=\"himg\" onclick=\"doExecute('Italic')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/nbsp.gif\" alt=\"空格\" class=\"himg\" onclick=\"doInsertBn()\"/></td>");
document.write("<td><img src=\"img/br.gif\" alt=\"换行\" class=\"himg\" onclick=\"doInsertBr()\"/></td>");
document.write("<td><img src=\"img/hr.gif\" alt=\"水平线\" class=\"himg\" onclick=\"doExecute('InsertHorizontalRule')\"/></td>");
document.write("<td><img src=\"img/sppage.gif\" alt=\"分页符\" class=\"himg\" onclick=\"doInsertSplitPage()\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/cut.gif\" alt=\"剪切\" class=\"himg\" onclick=\"doExecute('Cut')\"/></td>");
document.write("<td><img src=\"img/copy.gif\" alt=\"复制\" class=\"himg\" onclick=\"doExecute('Copy')\"/></td>");
document.write("<td><img src=\"img/par.gif\" alt=\"粘贴\" class=\"himg\" onclick=\"doExecute('Paste')\"/></td>");
document.write("<td><img src=\"img/parword.gif\" alt=\"从Word复制\" class=\"himg\" onclick=\"PasteWord()\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/quote.gif\" alt=\"引用\" class=\"himg\" onClick=\"doInsertQuote()\"/></td>");
document.write("<td><img src=\"img/group.gif\"alt=\"组分栏框\" class=\"himg\" onClick=\"doInsertGroup()\"/></td>");
document.write("<td>&nbsp;</td>");
document.write("</tr>");
document.write("</table>");
document.write("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr bgcolor=\"#cccccc\"><td height=\"1\"></td></tr>");
document.write("<tr bgcolor=\"#ffffff\"><td height=\"1\"></td></tr>");
document.write("</table>");